==> jira-projects-plugin-4.3.2.jar: static/components/pinnablenavigator/views/search/Search.js <==
(function(){
    "use strict";

    AJS.namespace("JIRA.Projects.PinnableNavigator.Views.Search.Search");

    JIRA.Projects.PinnableNavigator.Views.Search.Search = JIRA.Projects.Libs.Marionette.ItemView.extend({
        template: JIRA.Projects.PinnableNavigator.Search.Templates.searchBlock,
        ui: {
            searchInput: "input.js-subnav-filter-text",
            searchIcon: ".js-search-icon",
            clearIcon: ".js-clear-query"
        },

        events: {
            "keydown @ui.searchInput": "query",
            "click @ui.clearIcon": "clearQuery"
        },

        _numberIsNeededToShowTheList: 10,

        _searchValue: "",

        isSearchable: function () {
            return JIRA.Projects.PinnableNavigator.Search.isEnabled() && this.model.getAllItemsExceptButtons().length >= this._numberIsNeededToShowTheList;
        },

        isExisted: function () {
            return this.$el.closest("body").length;
        },

        getQuery: function () {
            if (this.isExisted()) {
                this._searchValue = AJS.$.trim(this.ui.searchInput.val());
            } else {
                this._searchValue = "";
            }

            return this._searchValue;
        },

        clearQuery: function () {
            if (this.isExisted()) {
                this._searchValue = "";
                this.ui.searchInput.val(this._searchValue).trigger("keydown");
            }
        },

        query: function () {
            setTimeout(_.bind(function(){
                this._searchValue = this.getQuery();
                if (this._searchValue !== "") {
                    this.ui.clearIcon.removeClass("hidden");
                    this.ui.searchIcon.addClass("hidden");
                } else {
                    this.ui.clearIcon.addClass("hidden");
                    this.ui.searchIcon.removeClass("hidden");
                }
                this.trigger("doQuery", this._searchValue);
            }, this), 0);
        },

        serializeData: function() {
            return {
                searchValue: this._searchValue,
                searchPlaceHolder: this.options.searchPlaceHolder
            };
        }
    });
}());

==> jira-projects-plugin-6.0.5.jar: static/components/pinnablenavigator/views/search/Search.js <==
define("jira/projects/components/pinnable-navigator/views/search/search", [
    "jira/projects/components/pinnable-navigator/search/templates",
    "jira/projects/components/pinnable-navigator/dark-feature",
    "jira/projects/libs/marionette",
    "underscore",
    "jquery"
], function(SearchTemplates, PinnableNavigatorDarkFeatures, Marionette, _, jQuery) {
    "use strict";

    return Marionette.ItemView.extend({
        template: SearchTemplates.searchBlock,
        ui: {
            searchInput: "input.js-subnav-filter-text",
            searchIcon: ".js-search-icon",
            clearIcon: ".js-clear-query"
        },

        events: {
            "keydown @ui.searchInput": "query",
            "click @ui.clearIcon": "clearQuery"
        },

        _numberIsNeededToShowTheList: 10,

        _searchValue: "",

        isSearchable: function () {
            return PinnableNavigatorDarkFeatures.isSearchEnabled() && this.model.getAllItemsExceptButtons().length >= this._numberIsNeededToShowTheList;
        },

        isExisted: function () {
            return this.$el.closest("body").length;
        },

        getQuery: function () {
            if (this.isExisted()) {
                this._searchValue = jQuery.trim(this.ui.searchInput.val());
            } else {
                this._searchValue = "";
            }

            return this._searchValue;
        },

        clearQuery: function () {
            if (this.isExisted()) {
                this._searchValue = "";
                this.ui.searchInput.val(this._searchValue).trigger("keydown");
            }
        },

        query: function () {
            setTimeout(_.bind(function(){
                this._searchValue = this.getQuery();
                if (this._searchValue !== "") {
                    this.ui.clearIcon.removeClass("hidden");
                    this.ui.searchIcon.addClass("hidden");
                } else {
                    this.ui.clearIcon.addClass("hidden");
                    this.ui.searchIcon.removeClass("hidden");
                }
                this.trigger("doQuery", this._searchValue);
            }, this), 0);
        },

        serializeData: function() {
            return {
                searchValue: this._searchValue,
                searchPlaceHolder: this.options.searchPlaceHolder
            };
        }
    });
});
